#
# spec file for package libfilezilla
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major		0
%define libname		%{name}%{major}
%define develname	%{name}-devel
Name:           libfilezilla
Version:        0.12.2
Release:        lp152.3.7
Summary:        C++ library for filezilla
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Url:            https://lib.filezilla-project.org/
Source0:        http://download.filezilla-project.org/libfilezilla/%{name}-%{version}.tar.bz2
Source1:        COPYING
Patch0:         %{name}-date-time.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(cppunit)
%if 0%{?suse_version} <= 1500
# FileZilla requires C++14 support.
BuildRequires:  gcc7-c++
%else
BuildRequires:  gcc-c++
%endif

%description
libfilezilla is C++ library, offering some basic functionality to
build high-performing, platform-independent programs. libfilezilla is
needed for filezilla (an FTP client and server) to build.

%package -n	%{libname}
Summary:        C++ library for filezilla
Group:          System/Libraries

%description -n	%{libname}
libfilezilla is C++ library, offering some basic functionality to
build high-performing, platform-independent programs. libfilezilla is
needed for filezilla (an FTP client and server) to build. Some of the
highlights include:

* A typesafe, multi-threaded event system.
* Timers for periodic events.
* A datetime class that not only tracks timestamp but also their accuracy,
  which simplifies dealing with timestamps originating from different sources.
* Simple process handling for spawning child processes with redirected I/O.

%package -n	%{develname}
Summary:        Development package for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}

%description -n	%{develname}
Files needed for development with %{name}.


%prep
%setup -q
%patch0
#copy in up to date GPL-2.0 license.
cp -v %{SOURCE1} .

%build
%if 0%{?suse_version} <= 1500
export CC="gcc-7"
export CXX="g++-7"
# Default ABI through G++4.9, thus the one wxWidgets uses.
export CXXFLAGS="%{optflags} -fabi-version=2 -fabi-compat-version=2"
%endif
autoreconf -fi
%configure --disable-static
make %{?_smp_mflags}

pushd doc
make %{?_smp_mflags} html
popd

%install
%makeinstall

# we don't want this
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_docdir}/%{develname}
cp -r doc/doxygen-doc/* %{buildroot}%{_docdir}/%{develname}/
rm -f %{buildroot}%{_docdir}/%{develname}/latex/refman.tex
%fdupes -s %{buildroot}%{_docdir}/%{develname}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc AUTHORS ChangeLog NEWS README COPYING
%{_libdir}/%{name}.so.%{major}*

%files -n %{develname}
%defattr(-,root,root)
%dir %{_docdir}/%{develname}
%{_docdir}/%{develname}/*
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue May  8 2018 ecsos@opensuse.org
- update to 0.12.2
  * New features:
  - Added parameters to base64_encode to control alphabet and
    padding
  - Improved performance of less_insensitive_ascii
  - *nix: Faster conversion between UTF-8 and wchar_t strings.
* Sat Feb 24 2018 ecsos@opensuse.org
- update to 0.12.1
  * New features:
  - Added fz::buffer::operator== and operator!=
  * Bugfixes and minor changes:
  - Fixed bug in fz::buffer::get(size_t)
- changes from 0.12.0
  * New features:
  - Added fz::datetime::operator bool
  - Added fz::datetime::get_rfc822 and fz::datetime::set_rfc822
* Thu Jan 25 2018 ecsos@opensuse.org
- update to 0.11.2
  * New features:
  - Added fz::starts_with and fz::ends_with
* Sun Nov 12 2017 ecsos@opensuse.org
- update to 0.11.1
  * New features:
  - Added fz::file::fsync() to sync data to disk
* Mon Oct  2 2017 ecsos@opensuse.org
- update to 0.11.0
  * New features:
  - Add fz::buffer class
  * Bugfixes and minor changes:
  - *nix: fz::process::spawn no longer calls async-signal-unsafe
    functions between forking and calling execv in the child.
* Fri Aug 25 2017 jengelh@inai.de
- RPM group fixes. Trim descriptions and make it more neutral.
* Sun Aug 20 2017 ecsos@opensuse.org
- update to 0.10.1
  * Bugfixes and minor changes:
  - MSW: Improve handling of reparse points in fz::local_filesys
* Sat Aug  5 2017 ecsos@opensuse.org
- update to 0.10.0
  * New features:
  - Added fz::percent_encode and fz::percent_encode
  - Added fz::uri and fz::query_string
  - Added fz::less_insensitive_ascii for case-insensitive strings
    in maps
  * Bugfixes and minor changes:
  - Moved encoding functions from string.hpp to encode.hpp
  - Use pkg-config instead of cppunit-config to look for cppunit.
- remove patch libfilezilla-fix_undefined_reference.patch because
  now in upstream
* Sun Jun  4 2017 ecsos@opensuse.org
- update to 0.9.2
  * New features:
  - Added fz::random_bytes to obtain a vector of the passed size
    of uniformly distributed random bytes
  - Added fz::ltrim and fz::rtim
  - Added parameter to trim functions which characters to trim
  - It is now possible to detach threads from async_task
- add patch libfilezilla-fix_undefined_reference.patch to prevent
  build error in filezilla
* Thu Feb 23 2017 ecsos@opensuse.org
- update to 0.9.1
  * New features:
  - Added a small helper function to fz::file to get the current
    position in the file
  - Added another version of fz::to_wstring_from_utf8 that takes
    a char buffer + length
  * Bugfixes and minor changes:
  - Fixed extraction of single-character tokens in fz::strtok
* Tue Dec  6 2016 ecsos@opensuse.org
- update to 0.9.0
  * New features:
  - Added parameter to fz::to_integral to specify which value is
    returned on error.
  - Added fz::remove_file
  - Added fz::hex_encode and fz::hex_decode
* Sun Nov 20 2016 ecsos@opensuse.org
- update to 0.8.0
  * New features:
  - Added fz::str_toupper_ascii to complement
    fz::str_tolower_ascii
  - Added fz::trim and fz::trimmed for removing leading and
    trailing whitespace from string
  - Added fz::str_is_ascii
  * Bugfixes and minor changes:
  - Fixed zero-padding for x and X string format conversion
    specifiers
- update to 0.7.1
  * Bugfixes and minor changes:
  - OS X: Work around a nasty bug in XCode where programs
    explicitly compiled for older versions of OS X were silently
    pulling in features exclusive to the new version, resulting
    in crashes at runtime
  - MSW: Fix detection of thread creation failures
* Sun Oct  2 2016 ecsos@opensuse.org
- update to 0.7.0
  * New features:
  - Add fz::base64_decode and fz::base64_encode
  - Add fz::strtok string tokenizer
  - Added non-throwing fz::to_integral
  - Implemented + (always sign) and - (left align) flags for
    fz::sprintf
* Fri Jul 29 2016 ecsos@opensuse.org
- update to 0.6.1
  * Bugfixes and minor changes:
  - Fix UTF-8 conversion functions and added a testcase
- update to 0.6.0
  * New features:
  - Add fz::sprintf, a safe replacement for for the C sprintf
    function
* Tue Jun 28 2016 ecsos@opensuse.org
- update to 0.5.3
  * New features:
  - Add fz::replace_substrincs to search and replace substrings
    in std::(w)string
  * Bugfixes and minor changes:
  - Explicitly request large file support on 32bit systems
* Sat May 28 2016 ecsos@opensuse.org
- update to 0.5.2
  * New features:
  - Add fz::shared_optional::is_same that checks whether
    two instances share the same underlying pointer value, like
    a shallow equal.
  - Add fz::int_to_hex_char as reverse to fz::hex_char_to_int
* Tue May 10 2016 ecsos@opensuse.org
- Update to version 0.5.1
  - Add constructore to sparse_optional taking pointers
  - Fix compilation on systems where iconv's second argument is
    const
* Wed Apr 27 2016 joerg.lorenzen@ki.tng.de
- Update to version 0.5.0
  - Handle timestamps where midnight is represented as 24:00:00.000
    of the previous day.
  - Fix inverted return value of fz::datetime::empty().
  - Increase performance of event loop if not using timers.
  - Better compatibility with runtimes that change the src pointer
    passed to mbsrtowcs or wcsrtombs.
* Fri Mar 11 2016 davejplater@gmail.com
- Added libfilezilla-date-time.patch.
* Sun Feb 28 2016 ecsos@opensuse.org
- update to 0.4.0.1
- Upstream changes:
  0.4.0.1 (2016-02-22)
  Fix compile error in testcase
  0.4.0 (2016-02-21)
  Added shared_optional and sparse_optional classes
  For more details see svn log:
  https://svn.filezilla-project.org/svn/libfilezilla
* Sun Feb 14 2016 davejplater@gmail.com
- Initial package created from PCLinuxOS src rpm
- Needed for filezilla to build.
